@@ -1,7 +1,7 @@
 """
 Type annotations for elb service client.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/)
 
 Usage::
 
@@ -93,7 +93,7 @@ class Exceptions:
 class ElasticLoadBalancingClient(BaseClient):
     """
     [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client)
-    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html)
+    [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/)
     """
 
     meta: ClientMeta
@@ -104,7 +104,7 @@ class ElasticLoadBalancingClient(BaseClient):
         ElasticLoadBalancingClient exceptions.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.exceptions)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#exceptions)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#exceptions)
         """
 
     def add_tags(
@@ -114,7 +114,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Adds the specified tags to the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.add_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#add_tags)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#add_tags)
         """
 
     def apply_security_groups_to_load_balancer(
@@ -125,7 +125,7 @@ class ElasticLoadBalancingClient(BaseClient):
         private cloud (VPC).
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.apply_security_groups_to_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#apply_security_groups_to_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#apply_security_groups_to_load_balancer)
         """
 
     def attach_load_balancer_to_subnets(
@@ -136,7 +136,7 @@ class ElasticLoadBalancingClient(BaseClient):
         balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.attach_load_balancer_to_subnets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#attach_load_balancer_to_subnets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#attach_load_balancer_to_subnets)
         """
 
     def can_paginate(self, operation_name: str) -> bool:
@@ -144,7 +144,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Check if an operation can be paginated.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.can_paginate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#can_paginate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#can_paginate)
         """
 
     def configure_health_check(
@@ -155,7 +155,7 @@ class ElasticLoadBalancingClient(BaseClient):
         your EC2 instances.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.configure_health_check)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#configure_health_check)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#configure_health_check)
         """
 
     def create_app_cookie_stickiness_policy(
@@ -166,7 +166,7 @@ class ElasticLoadBalancingClient(BaseClient):
         an application-generated cookie.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.create_app_cookie_stickiness_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_app_cookie_stickiness_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#create_app_cookie_stickiness_policy)
         """
 
     def create_lb_cookie_stickiness_policy(
@@ -177,7 +177,7 @@ class ElasticLoadBalancingClient(BaseClient):
         lifetime of the browser (user-agent) or a specified expiration period.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.create_lb_cookie_stickiness_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_lb_cookie_stickiness_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#create_lb_cookie_stickiness_policy)
         """
 
     def create_load_balancer(
@@ -195,7 +195,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Creates a Classic Load Balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#create_load_balancer)
         """
 
     def create_load_balancer_listeners(
@@ -205,7 +205,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Creates one or more listeners for the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_listeners)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_listeners)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#create_load_balancer_listeners)
         """
 
     def create_load_balancer_policy(
@@ -220,7 +220,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Creates a policy with the specified attributes for the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.create_load_balancer_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#create_load_balancer_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#create_load_balancer_policy)
         """
 
     def delete_load_balancer(self, *, LoadBalancerName: str) -> Dict[str, Any]:
@@ -228,7 +228,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Deletes the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#delete_load_balancer)
         """
 
     def delete_load_balancer_listeners(
@@ -238,7 +238,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Deletes the specified listeners from the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_listeners)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_listeners)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#delete_load_balancer_listeners)
         """
 
     def delete_load_balancer_policy(
@@ -248,7 +248,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Deletes the specified policy from the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.delete_load_balancer_policy)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#delete_load_balancer_policy)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#delete_load_balancer_policy)
         """
 
     def deregister_instances_from_load_balancer(
@@ -258,7 +258,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Deregisters the specified instances from the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.deregister_instances_from_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#deregister_instances_from_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#deregister_instances_from_load_balancer)
         """
 
     def describe_account_limits(
@@ -269,7 +269,7 @@ class ElasticLoadBalancingClient(BaseClient):
         account.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_account_limits)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_account_limits)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_account_limits)
         """
 
     def describe_instance_health(
@@ -280,7 +280,7 @@ class ElasticLoadBalancingClient(BaseClient):
         load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_instance_health)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_instance_health)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_instance_health)
         """
 
     def describe_load_balancer_attributes(
@@ -290,7 +290,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Describes the attributes for the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_attributes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_attributes)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_load_balancer_attributes)
         """
 
     def describe_load_balancer_policies(
@@ -300,7 +300,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Describes the specified policies.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policies)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policies)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_load_balancer_policies)
         """
 
     def describe_load_balancer_policy_types(
@@ -311,7 +311,7 @@ class ElasticLoadBalancingClient(BaseClient):
         types.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancer_policy_types)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancer_policy_types)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_load_balancer_policy_types)
         """
 
     def describe_load_balancers(
@@ -321,7 +321,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Describes the specified the load balancers.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_load_balancers)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_load_balancers)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_load_balancers)
         """
 
     def describe_tags(self, *, LoadBalancerNames: Sequence[str]) -> DescribeTagsOutputTypeDef:
@@ -329,7 +329,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Describes the tags associated with the specified load balancers.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.describe_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#describe_tags)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#describe_tags)
         """
 
     def detach_load_balancer_from_subnets(
@@ -340,7 +340,7 @@ class ElasticLoadBalancingClient(BaseClient):
         balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.detach_load_balancer_from_subnets)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#detach_load_balancer_from_subnets)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#detach_load_balancer_from_subnets)
         """
 
     def disable_availability_zones_for_load_balancer(
@@ -351,7 +351,7 @@ class ElasticLoadBalancingClient(BaseClient):
         the specified load balancer in EC2-Classic or a default VPC.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.disable_availability_zones_for_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#disable_availability_zones_for_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#disable_availability_zones_for_load_balancer)
         """
 
     def enable_availability_zones_for_load_balancer(
@@ -362,7 +362,7 @@ class ElasticLoadBalancingClient(BaseClient):
         specified load balancer in EC2-Classic or a default VPC.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.enable_availability_zones_for_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#enable_availability_zones_for_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#enable_availability_zones_for_load_balancer)
         """
 
     def generate_presigned_url(
@@ -376,7 +376,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Generate a presigned url given a client, its method, and arguments.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.generate_presigned_url)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#generate_presigned_url)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#generate_presigned_url)
         """
 
     def modify_load_balancer_attributes(
@@ -386,7 +386,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Modifies the attributes of the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.modify_load_balancer_attributes)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#modify_load_balancer_attributes)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#modify_load_balancer_attributes)
         """
 
     def register_instances_with_load_balancer(
@@ -396,7 +396,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Adds the specified instances to the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.register_instances_with_load_balancer)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#register_instances_with_load_balancer)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#register_instances_with_load_balancer)
         """
 
     def remove_tags(
@@ -406,7 +406,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Removes one or more tags from the specified load balancer.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.remove_tags)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#remove_tags)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#remove_tags)
         """
 
     def set_load_balancer_listener_ssl_certificate(
@@ -416,7 +416,7 @@ class ElasticLoadBalancingClient(BaseClient):
         Sets the certificate that terminates the specified listener's SSL connections.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_listener_ssl_certificate)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_listener_ssl_certificate)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#set_load_balancer_listener_ssl_certificate)
         """
 
     def set_load_balancer_policies_for_backend_server(
@@ -427,7 +427,7 @@ class ElasticLoadBalancingClient(BaseClient):
         instance is listening with a new set of policies.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_for_backend_server)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_for_backend_server)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#set_load_balancer_policies_for_backend_server)
         """
 
     def set_load_balancer_policies_of_listener(
@@ -438,7 +438,7 @@ class ElasticLoadBalancingClient(BaseClient):
         the specified set of policies.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.set_load_balancer_policies_of_listener)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#set_load_balancer_policies_of_listener)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#set_load_balancer_policies_of_listener)
         """
 
     @overload
@@ -447,7 +447,7 @@ class ElasticLoadBalancingClient(BaseClient):
     ) -> DescribeAccountLimitsPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#get_paginator)
         """
 
     @overload
@@ -456,7 +456,7 @@ class ElasticLoadBalancingClient(BaseClient):
     ) -> DescribeLoadBalancersPaginator:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.get_paginator)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#get_paginator)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#get_paginator)
         """
 
     @overload
@@ -465,7 +465,7 @@ class ElasticLoadBalancingClient(BaseClient):
     ) -> AnyInstanceInServiceWaiter:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.get_waiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#get_waiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#get_waiter)
         """
 
     @overload
@@ -474,12 +474,12 @@ class ElasticLoadBalancingClient(BaseClient):
     ) -> InstanceDeregisteredWaiter:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.get_waiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#get_waiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#get_waiter)
         """
 
     @overload
     def get_waiter(self, waiter_name: Literal["instance_in_service"]) -> InstanceInServiceWaiter:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/elb.html#ElasticLoadBalancing.Client.get_waiter)
-        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client.html#get_waiter)
+        [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_elb/client/#get_waiter)
         """
